# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from PyQt4.QtCore import *

from hashconfigdialog import HashConfigDialog


class SettingsConfig:
    '''Class providing an interface to launch the configuration dialog and view results
    The backing store for the configuration is the QSettings object, which will save 
    options in an OS-dependent location (config file or Windows registry)'''
    def __init__(self):
        self.settings = QSettings('pyaniqthasher')

    def showDialog(self):
        d = HashConfigDialog()
        d.usernameField.setText(self.username())
        d.passwordField.setText(self.password())
        d.hostField.setText(self.hostname())
        d.portField.setText(str(self.port()))
        d.directoryField.setText(self.directory())
        d.encryptionBox.setChecked(self.encryption())
        d.apikeyField.setEnabled(self.encryption())
        d.apikeyField.setText(self.apikey())

        status = d.exec_()

        if (status == HashConfigDialog.Accepted):
            self.settings.setValue('username',d.usernameField.text())
            self.settings.setValue('password',d.passwordField.text())
            self.settings.setValue('hostname',d.hostField.text())
            self.settings.setValue('port',d.portField.text())
            self.settings.setValue('directory',d.directoryField.text())
            self.settings.setValue('encryption',d.encryptionBox.isChecked())
            self.settings.setValue('apikey',d.apikeyField.text())
        return status


    def username(self):
        return self.settings.value('username').toString()
    def password(self):
        return self.settings.value('password').toString()
    def hostname(self):
        return self.settings.value('hostname','api.anidb.net').toString()
    def port(self):
        return self.settings.value('port',9000).toInt()[0]
    def directory(self):
        return self.settings.value('directory').toString()
    def encryption(self):
        return self.settings.value('encryption').toBool()
    def apikey(self):
        return self.settings.value('apikey').toString()

class SessionConfig:
    '''Class storing the same options as SettingsConfig, but without writing to an external config file/registry.
       The settings only last for a specific session'''
    def __init__(self):
        self._sconfig = SettingsConfig()
        self._username = self._sconfig.username()
        self._password = self._sconfig.password()
        self._hostname = self._sconfig.hostname()
        self._port = self._sconfig.port()
        self._directory = self._sconfig.directory()
        self._encryption = self._sconfig.encryption()
        self._apikey = self._sconfig.apikey()

    def showDialog(self):
        d = HashConfigDialog()
        d.setWindowTitle("Session-only Config")
        d.usernameField.setText(self.username())
        d.passwordField.setText(self.password())
        d.hostField.setText(self.hostname())
        d.portField.setText(str(self.port()))
        d.directoryField.setText(self.directory())
        d.encryptionBox.setChecked(self.encryption())
        d.apikeyField.setEnabled(self.encryption())
        d.apikeyField.setText(self.apikey())

        status = d.exec_()

        if (status == HashConfigDialog.Accepted):
            self._username = d.usernameField.text()
            self._password = d.passwordField.text()
            self._hostname = d.hostField.text()
            self._port = d.portField.text()
            self._directory = d.directoryField.text()
            self._encryption = d.encryptionBox.isChecked()
            self._apikey = d.apikeyField.text()
        return status

    def username(self):
        return self._username
    def password(self):
        return self._password
    def hostname(self):
        return self._hostname
    def port(self):
        return self._port
    def directory(self):
        return self._directory
    def encryption(self):
        return self._encryption
    def apikey(self):
        return self._apikey

CONFIG = SettingsConfig()
